package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.conference.SysUserConference;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * 参会人员Mapper接口
 * 
 * @author boman
 * @date 2024-05-06
 */
public interface SysUserConferenceMapper 
{
    /**
     * 查询参会人员
     * 
     * @param conferenceId 参会人员主键
     * @return 参会人员
     */
    public SysUserConference selectSysUserConferenceByConferenceId(Long conferenceId);

    /**
     * 查询参会人员列表
     * 
     * @param sysUserConference 参会人员
     * @return 参会人员集合
     */
    public List<SysUserConference> selectSysUserConferenceList(SysUserConference sysUserConference);

    /**
     * 新增参会人员
     * 
     * @param sysUserConference 参会人员
     * @return 结果
     */
    public int insertSysUserConference(SysUserConference sysUserConference);

    /**
     * 批量保存
     * @param sysUserConferenceList
     * @return
     */
    public int batchSysUserConference(List<SysUserConference> sysUserConferenceList);

    /**
     * 修改参会人员
     * 
     * @param sysUserConference 参会人员
     * @return 结果
     */
    public int updateSysUserConference(SysUserConference sysUserConference);

    /**
     * 删除参会人员
     * 
     * @param conferenceId 参会人员主键
     * @return 结果
     */
    public int deleteSysUserConferenceByConferenceId(Long conferenceId);

    /**
     * 批量删除参会人员
     * 
     * @param conferenceIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysUserConferenceByConferenceIds(Long[] conferenceIds);

    void updateSysUserConferenceByUserId(SysUserConference sysUserConference);

    void deleteSysUserConferenceByTime(@Param("reviewTime") String reviewTime, @Param("loanApplicationId")Long loanApplicationId);

    SysUserConference selectSysUserConferenceNew(@Param("loanApplicationId")Long loanApplicationId);
}
